##  Configuring a Fact Sheet
Follow these steps:
  1. Navigate to the fact sheet configuration page in one of the following ways:
     * In the Meta Model Configuration section of the administration area, select a fact sheet type.
     * In the inventory, select a fact sheet of the type that you need. On the fact sheet page, in the upper-right corner, click More actions (three-dot icon) > Configuration.
  2. On the fact sheet configuration page, adjust the configuration as needed. To learn more about specific settings, see [Fact Sheet Settings](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275955467a441014a5dce078bf2e383c__fact_sheet_settings).
![Configuring the Application Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752e8907a441014bc9c892364a73714_LowRes.png)
Configuring the Application Fact Sheet
  3. Save the changes. If prompted, review the changes before saving them.
